@@ -1,6 +1,6 @@
 //
 // R package splines2 by Wenjie Wang and Jun Yan
-// Copyright (C) 2016-2022
+// Copyright (C) 2016-2023
 //
 // This file is part of the R package splines2.
 //
@@ -18,6 +18,10 @@
 #ifndef SPLINES2_ARMADILLO_H
 #define SPLINES2_ARMADILLO_H
 
+#ifndef ARMA_NO_DEBUG
+#define ARMA_NO_DEBUG
+#endif
+
 #include "splines2Armadillo/BSpline.h"
 #include "splines2Armadillo/MSpline.h"
 #include "splines2Armadillo/ISpline.h"
